eyepy.core package
==================

Submodules
----------

eyepy.core.base module
----------------------

.. automodule:: eyepy.core.base
    :members:
    :undoc-members:
    :show-inheritance:

eyepy.core.config module
------------------------

.. automodule:: eyepy.core.config
    :members:
    :undoc-members:
    :show-inheritance:

eyepy.core.drusen module
------------------------

.. automodule:: eyepy.core.drusen
    :members:
    :undoc-members:
    :show-inheritance:

eyepy.core.quantifier module
----------------------------

.. automodule:: eyepy.core.quantifier
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: eyepy.core
    :members:
    :undoc-members:
    :show-inheritance:
